==> zio-aws-sagemaker_3-5.17.148.1-sources.jar: zio/aws/sagemaker/model/DomainSettingsForUpdate.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class DomainSettingsForUpdate(
    rStudioServerProDomainSettingsForUpdate: Option[
      zio.aws.sagemaker.model.RStudioServerProDomainSettingsForUpdate
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.DomainSettingsForUpdate = {
    import DomainSettingsForUpdate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.DomainSettingsForUpdate
      .builder()
      .optionallyWith(
        rStudioServerProDomainSettingsForUpdate.map(value =>
          value.buildAwsValue()
        )
      )(_.rStudioServerProDomainSettingsForUpdate)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.DomainSettingsForUpdate.ReadOnly =
    zio.aws.sagemaker.model.DomainSettingsForUpdate.wrap(buildAwsValue())
}
object DomainSettingsForUpdate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.DomainSettingsForUpdate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.DomainSettingsForUpdate =
      zio.aws.sagemaker.model.DomainSettingsForUpdate(
        rStudioServerProDomainSettingsForUpdate.map(value => value.asEditable)
      )
    def rStudioServerProDomainSettingsForUpdate: Option[
      zio.aws.sagemaker.model.RStudioServerProDomainSettingsForUpdate.ReadOnly
    ]
    def getRStudioServerProDomainSettingsForUpdate: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.RStudioServerProDomainSettingsForUpdate.ReadOnly
    ] = AwsError.unwrapOptionField(
      "rStudioServerProDomainSettingsForUpdate",
      rStudioServerProDomainSettingsForUpdate
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.DomainSettingsForUpdate
  ) extends zio.aws.sagemaker.model.DomainSettingsForUpdate.ReadOnly {
    override val rStudioServerProDomainSettingsForUpdate: Option[
      zio.aws.sagemaker.model.RStudioServerProDomainSettingsForUpdate.ReadOnly
    ] = scala
      .Option(impl.rStudioServerProDomainSettingsForUpdate())
      .map(value =>
        zio.aws.sagemaker.model.RStudioServerProDomainSettingsForUpdate
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.DomainSettingsForUpdate
  ): zio.aws.sagemaker.model.DomainSettingsForUpdate.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-sagemaker_3-5.17.182.1-sources.jar: zio/aws/sagemaker/model/DomainSettingsForUpdate.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DomainSettingsForUpdate(
    rStudioServerProDomainSettingsForUpdate: Optional[
      zio.aws.sagemaker.model.RStudioServerProDomainSettingsForUpdate
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.DomainSettingsForUpdate = {
    import DomainSettingsForUpdate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.DomainSettingsForUpdate
      .builder()
      .optionallyWith(
        rStudioServerProDomainSettingsForUpdate.map(value =>
          value.buildAwsValue()
        )
      )(_.rStudioServerProDomainSettingsForUpdate)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.DomainSettingsForUpdate.ReadOnly =
    zio.aws.sagemaker.model.DomainSettingsForUpdate.wrap(buildAwsValue())
}
object DomainSettingsForUpdate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.DomainSettingsForUpdate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.DomainSettingsForUpdate =
      zio.aws.sagemaker.model.DomainSettingsForUpdate(
        rStudioServerProDomainSettingsForUpdate.map(value => value.asEditable)
      )
    def rStudioServerProDomainSettingsForUpdate: Optional[
      zio.aws.sagemaker.model.RStudioServerProDomainSettingsForUpdate.ReadOnly
    ]
    def getRStudioServerProDomainSettingsForUpdate: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.RStudioServerProDomainSettingsForUpdate.ReadOnly
    ] = AwsError.unwrapOptionField(
      "rStudioServerProDomainSettingsForUpdate",
      rStudioServerProDomainSettingsForUpdate
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.DomainSettingsForUpdate
  ) extends zio.aws.sagemaker.model.DomainSettingsForUpdate.ReadOnly {
    override val rStudioServerProDomainSettingsForUpdate: Optional[
      zio.aws.sagemaker.model.RStudioServerProDomainSettingsForUpdate.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.rStudioServerProDomainSettingsForUpdate())
      .map(value =>
        zio.aws.sagemaker.model.RStudioServerProDomainSettingsForUpdate
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.DomainSettingsForUpdate
  ): zio.aws.sagemaker.model.DomainSettingsForUpdate.ReadOnly = new Wrapper(
    impl
  )
}
